/*Class description: The Adversary class is an abstract that extends GameCharacter. Every adversary (opponent)
 * can be blinded and charmed for some amount of period. Hence this class keeps track of the
 * blindTimer/charmTimer of an opponent.
 */
public abstract class Adversary extends GameCharacter {
	int blindTimer = 0;
	int charmTimer = 0;

	public Adversary(String name, char type, int xIn, int yIn) {
		super(name, type, xIn, yIn);
	}

	//Returns true if spell can be cast on adversary. An abstract method that is defined
	//in child classes that extend the Adversary class
	abstract boolean getSpellCast(Move spell);
	//Returns true if blindTimer has down to 0
	public boolean isBlind() {
		return (blindTimer == 0) ? false : true;
	}
	//Returns true if charmTimer is down to 0
	public boolean isCharmed() {
		return (charmTimer == 0) ? false : true;
	}
	//An abstract method that decrements the blindTimer and charmTimer. Defined in
	//child classes that extend the Adversary class
	abstract void wakeUp();
}
